==> ydoc-4.0.6.tgz: package/README.md <==
<p align="center">
  <a href="https://ydoc.ymfe.org/">
    <img src="https://ws1.sinaimg.cn/large/006FkmqZly1fpswv9gzalj305e05ft98.jpg" width="194" alt="logo" srcSet="https://ws1.sinaimg.cn/large/006FkmqZly1fpswvk5qsyj30as0au75x.jpg 2x" />
  </a>
</p>

## YDoc

![npm (tag)](https://img.shields.io/npm/v/ydoc.svg)
![npm (tag)](https://img.shields.io/npm/v/ydoc/rc.svg)
![npm](https://img.shields.io/npm/dm/localeval.svg)
![license](https://img.shields.io/github/license/YMFE/ydoc.svg)

YDoc 是一个优雅的文档站构建工具，能够基于 markdown 轻松生成完整静态站点，让你专注于文档写作。YDoc 拥有灵活而强大的插件 / 主题机制，开发者可以轻松定制属于自己的文档站点。

我们使用 `🐶` 作为我们的 LOGO，狗狗作为人类的好朋友，有着敏捷、灵动的特点：YDoc 正是这样一个工具 👻

[文档首页](https://ydoc.ymfe.org/) | [README in English](https://github.com/YMFE/ydoc/blob/master/README-en.md)

## 用法

### 安装
```
npm install -g ydoc
```

### 安装 rc 版本（发布候选版本）
```
npm install ydoc@rc [-g]
```

## 创建站点
```
ydoc init
ydoc build
```

## 插件

- [ydoc-plugin-copy](https://www.npmjs.com/package/ydoc-plugin-copy): 用于快速复制 markdown 生成页面的代码片段。
- [ydoc-plugin-import-asset](https://www.npmjs.com/package/ydoc-plugin-import-asset): 在页面中引入 js 与 css 文件
- [ydoc-plugin-jsdoc](https://www.npmjs.com/package/ydoc-plugin-jsdoc): 根据代码注释生成文档，基于 jsdoc
- [ydoc-plugin-pangu](https://www.npmjs.com/package/ydoc-plugin-pangu): 自动替你在网页中所有的中文字和半形的英文、数字、符号之间插入空白(盘古之白)
- [more... ](https://ydoc.ymfe.org/plugin/index.html)

## 开发者

- [dwb1994](https://github.com/dwb1994) (dev & design)
- [sean1025](https://github.com/hellosean1025) (dev)
- [zwjamnsss](https://github.com/amnsss) (dev & design)

我们非常欢迎社区的同学参与开发，欢迎提 [pull requests](https://github.com/YMFE/ydoc/pulls) 来帮助我们完善程序，也欢迎社区的同学为 YDoc 开发[插件](https://ydoc.ymfe.org/plugin/index.html)。

同时也欢迎大家对 YDoc 提出宝贵的意见或建议：[github issues](https://github.com/YMFE/ydoc/issues)

==> ydoc-4.1.2.tgz: package/README.md <==
<p align="center">
  <a href="https://https://hellosean1025.github.io/ydoc/">
    <img src="https://ws1.sinaimg.cn/large/006FkmqZly1fpswv9gzalj305e05ft98.jpg" width="194" alt="logo" srcSet="https://ws1.sinaimg.cn/large/006FkmqZly1fpswvk5qsyj30as0au75x.jpg 2x" />
  </a>
</p>

## YDoc

![npm (tag)](https://img.shields.io/npm/v/ydoc.svg)
![npm (tag)](https://img.shields.io/npm/v/ydoc/rc.svg)
![npm](https://img.shields.io/npm/dm/localeval.svg)
![license](https://img.shields.io/github/license/YMFE/ydoc.svg)

YDoc 是一个优雅的文档站构建工具，能够基于 markdown 轻松生成完整静态站点，让你专注于文档写作。YDoc 拥有灵活而强大的插件 / 主题机制，开发者可以轻松定制属于自己的文档站点。

我们使用 `🐶` 作为我们的 LOGO，狗狗作为人类的好朋友，有着敏捷、灵动的特点：YDoc 正是这样一个工具 👻

[文档首页](https://hellosean1025.github.io/ydoc/) | [README in English](https://github.com/YMFE/ydoc/blob/master/README-en.md)

## 用法

### 安装
```
npm install -g ydoc
```

### 安装 rc 版本（发布候选版本）
```
npm install ydoc@rc [-g]
```

## 创建站点
```
ydoc init
ydoc build
```

## 插件

- [ydoc-plugin-copy](https://www.npmjs.com/package/ydoc-plugin-copy): 用于快速复制 markdown 生成页面的代码片段。
- [ydoc-plugin-import-asset](https://www.npmjs.com/package/ydoc-plugin-import-asset): 在页面中引入 js 与 css 文件
- [ydoc-plugin-jsdoc](https://www.npmjs.com/package/ydoc-plugin-jsdoc): 根据代码注释生成文档，基于 jsdoc
- [ydoc-plugin-pangu](https://www.npmjs.com/package/ydoc-plugin-pangu): 自动替你在网页中所有的中文字和半形的英文、数字、符号之间插入空白(盘古之白)
- [more... ](https://hellosean1025.github.io/ydoc/plugin/index.html)

## 主题

- [ydoc-theme-demo](https://www.npmjs.com/package/ydoc-theme-demo)
- [ydoc-theme-dark](https://www.npmjs.com/package/ydoc-theme-dark)

## 开发者

- [dwb1994](https://github.com/dwb1994) (dev & design)
- [lwg529](https://github.com/lwg529) (dev)
- [sean1025](https://github.com/hellosean1025) (dev)
- [zwjamnsss](https://github.com/amnsss) (dev & design)

我们非常欢迎社区的同学参与开发，欢迎提 [pull requests](https://github.com/YMFE/ydoc/pulls) 来帮助我们完善程序，也欢迎社区的同学为 YDoc 开发[插件](https://hellosean1025.github.io/ydoc/plugin/index.html)。

同时也欢迎大家对 YDoc 提出宝贵的意见或建议：[github issues](https://github.com/YMFE/ydoc/issues)
